==> polymer-sound-patcher-0.14.1+1.21.9-sources.jar: eu/pb4/polymer/soundpatcher/mixin/block/BlockItemMixin.java <==
package eu.pb4.polymer.soundpatcher.mixin.block;

import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import eu.pb4.polymer.soundpatcher.impl.CoreBridge;
import eu.pb4.polymer.soundpatcher.impl.SoundRemapperImpl;
import net.minecraft.class_1297;
import net.minecraft.class_1747;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_3414;
import net.minecraft.class_3419;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import xyz.nucleoid.packettweaker.PacketContext;


@Mixin(class_1747.class)
public abstract class BlockItemMixin {
    @WrapOperation(method = "place(Lnet/minecraft/item/ItemPlacementContext;)Lnet/minecraft/util/ActionResult;", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/World;playSound(Lnet/minecraft/entity/Entity;Lnet/minecraft/util/math/BlockPos;Lnet/minecraft/sound/SoundEvent;Lnet/minecraft/sound/SoundCategory;FF)V"))
    private void wrapPlaySound(class_1937 instance, class_1297 source, class_2338 pos, class_3414 sound, class_3419 category, float volume, float pitch, Operation<Void> original, @Local(ordinal = 1) class_2680 state) {
        original.call(instance,
                SoundRemapperImpl.ignoreExceptions(CoreBridge.getClientSideSoundGroup(state, PacketContext.create(instance.method_30349())).method_10598()) ? null : source,
                pos, sound, category, volume, pitch);
    }

}

==> polymer-sound-patcher-0.15.0+1.21.11-sources.jar: eu/pb4/polymer/soundpatcher/mixin/block/BlockItemMixin.java <==
package eu.pb4.polymer.soundpatcher.mixin.block;

import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import eu.pb4.polymer.soundpatcher.impl.CoreBridge;
import eu.pb4.polymer.soundpatcher.impl.SoundRemapperImpl;
import net.minecraft.class_1297;
import net.minecraft.class_1747;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_3414;
import net.minecraft.class_3419;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import xyz.nucleoid.packettweaker.PacketContext;


@Mixin(class_1747.class)
public abstract class BlockItemMixin {
    @WrapOperation(method = "place(Lnet/minecraft/world/item/context/BlockPlaceContext;)Lnet/minecraft/world/InteractionResult;", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/level/Level;playSound(Lnet/minecraft/world/entity/Entity;Lnet/minecraft/core/BlockPos;Lnet/minecraft/sounds/SoundEvent;Lnet/minecraft/sounds/SoundSource;FF)V"))
    private void wrapPlaySound(class_1937 instance, class_1297 source, class_2338 pos, class_3414 sound, class_3419 category, float volume, float pitch, Operation<Void> original, @Local(ordinal = 1) class_2680 state) {
        original.call(instance,
                SoundRemapperImpl.ignoreExceptions(CoreBridge.getClientSideSoundGroup(state, PacketContext.create(instance.method_30349())).method_10598()) ? null : source,
                pos, sound, category, volume, pitch);
    }

}
